smartcard.pcsc.PCSCExceptions.ReleaseContextException

# ``smartcard`.`pcsc`.`PCSCExceptions`.`ReleaseContextException``

exception documentation

`class ReleaseContextException(BaseSCardException):`

View In Hierarchy

Raised when scard failed to release PCSC context.

Method | `__init__` | Constructor that stores the pcsc error status.

Inherited from `BaseSCardException`:

Method | `__str__` | Returns a string representation of the exception.
Instance Variable | `hresult` | Undocumented
Instance Variable | `message` | Undocumented

def __init__(self, hresult):
overrides `smartcard.pcsc.PCSCExceptions.BaseSCardException.__init__`

Constructor that stores the pcsc error status.